@@ -5,7 +5,9 @@ use utf8;
 
 package Neo4j::Driver::Type::Path;
 # ABSTRACT: Directed sequence of relationships between two nodes
-$Neo4j::Driver::Type::Path::VERSION = '0.17';
+$Neo4j::Driver::Type::Path::VERSION = '0.18';
+
+use overload '@{}' => \&_array, fallback => 1;
 
 use Carp qw(croak);
 
@@ -14,8 +16,8 @@ sub nodes {
 	my ($self) = @_;
 	
 	croak 'nodes() in scalar context not supported' unless wantarray;
-	my @nodes = grep { ref eq 'Neo4j::Driver::Type::Node' } @$self;
-	return @nodes;
+	my $i = 0;
+	return grep { ++$i & 1 } @{$self->{path}};
 }
 
 
@@ -23,15 +25,41 @@ sub relationships {
 	my ($self) = @_;
 	
 	croak 'relationships() in scalar context not supported' unless wantarray;
-	my @rels = grep { ref eq 'Neo4j::Driver::Type::Relationship' } @$self;
-	return @rels;
+	my $i = 0;
+	return grep { $i++ & 1 } @{$self->{path}};
+}
+
+
+sub elements {
+	my ($self) = @_;
+	
+	croak 'elements() in scalar context not supported' unless wantarray;
+	return @{$self->{path}};
 }
 
 
 sub path {
 	my ($self) = @_;
 	
-	return [ @$self ];
+	warnings::warnif deprecated => __PACKAGE__ . "->path() is deprecated; use elements()";
+	return [ @{$self->{path}} ];
+}
+
+
+sub _array {
+	my ($self) = @_;
+	
+	warnings::warnif deprecated => "Direct array access is deprecated; use " . __PACKAGE__ . "->elements()";
+	return $self->{path};
+}
+
+
+# for experimental Cypher type system customisation only
+sub _private {
+	my ($self) = @_;
+	
+	$self->{private} //= {};
+	return $self->{private};
 }
 
 
@@ -49,7 +77,7 @@ Neo4j::Driver::Type::Path - Directed sequence of relationships between two nodes
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
@@ -58,6 +86,8 @@ version 0.17
  
  ($node_a, $node_b) = $path->nodes;
  ($relationship_k)  = $path->relationships;
+ 
+ ($a, $k, $b) = $path->elements;
 
 =head1 DESCRIPTION
 
@@ -72,6 +102,13 @@ start and the end of the path.
 
 L<Neo4j::Driver::Type::Path> implements the following methods.
 
+=head2 elements
+
+ @all = $path->elements;
+
+Return the path as a list alternating between nodes
+and relationships in path sequence order.
+
 =head2 nodes
 
  @nodes = $path->nodes;
@@ -106,37 +143,18 @@ these features.
 
 =head2 Calling in scalar context
 
+ $all   = $path->elements;  # fails
  $nodes = $path->nodes;  # fails
  $rels  = $path->relationships;  # fails
 
-The C<nodes()> and C<relationships()> methods C<die> if called in
-scalar context.
-
-=head2 Direct data structure access
-
- $start_node = $path->[0];
-
-Currently, the paths's sequence may be directly accessed as if
-the path was a simple arrayref. This is a concession to backwards
-compatibility, as the data structure only started being blessed
-as an object in version 0.13.
-
-Relying on this implementation detail is deprecated.
-Use the accessor methods C<nodes> and C<relationships> instead.
-
-=head2 Path as alternating array
-
- $array = $path->path;
-
-Return the path as an array reference, alternating between nodes
-and relationships in path sequence order. This is similar to
-L<REST::Neo4p::Path>'s C<as_simple()> method.
+The C<elements()>, C<nodes()>, and C<relationships()> methods
+C<die> if called in scalar context.
 
 =head1 BUGS
 
 When paths are returned via HTTP, the objects accessible via
-C<nodes()> and C<relationships()> lack meta data for their labels
-and types. This is due to an issue in the Neo4j server.
+C<elements()>, C<nodes()>, and C<relationships()> lack meta data for
+their labels and types. This is due to an issue in the Neo4j server.
 
 =head1 SEE ALSO
 
