@@ -5,40 +5,43 @@ use utf8;
 
 package Neo4j::Driver::Type::Relationship;
 # ABSTRACT: Describes a relationship from a Neo4j graph
-$Neo4j::Driver::Type::Relationship::VERSION = '0.17';
+$Neo4j::Driver::Type::Relationship::VERSION = '0.18';
+
+use overload '%{}' => \&_hash, fallback => 1;
+
 
 sub get {
 	my ($self, $property) = @_;
 	
-	return $self->{$property};
+	return $$self->{$property};
 }
 
 
 sub type {
 	my ($self) = @_;
 	
-	return $self->{_meta}->{type};
+	return $$self->{_meta}->{type};
 }
 
 
 sub start_id {
 	my ($self) = @_;
 	
-	return $self->{_meta}->{start};
+	return $$self->{_meta}->{start};
 }
 
 
 sub end_id {
 	my ($self) = @_;
 	
-	return $self->{_meta}->{end};
+	return $$self->{_meta}->{end};
 }
 
 
 sub properties {
 	my ($self) = @_;
 	
-	my $properties = { %$self };
+	my $properties = { %$$self };
 	delete $properties->{_meta};
 	return $properties;
 }
@@ -47,14 +50,30 @@ sub properties {
 sub id {
 	my ($self) = @_;
 	
-	return $self->{_meta}->{id};
+	return $$self->{_meta}->{id};
 }
 
 
 sub deleted {
 	my ($self) = @_;
 	
-	return $self->{_meta}->{deleted};
+	return $$self->{_meta}->{deleted};
+}
+
+
+sub _hash {
+	my ($self) = @_;
+	
+	warnings::warnif deprecated => "Direct hash access is deprecated; use " . __PACKAGE__ . "->properties()";
+	return $$self;
+}
+
+
+# for experimental Cypher type system customisation only
+sub _private {
+	my ($self) = @_;
+	
+	return $$self;
 }
 
 
@@ -72,7 +91,7 @@ Neo4j::Driver::Type::Relationship - Describes a relationship from a Neo4j graph
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
@@ -158,18 +177,6 @@ experimental features. These are subject to unannounced modification
 or removal in future versions. Expect your code to break if you
 depend upon these features.
 
-=head2 Direct data structure access
-
- $property_value = $relationship->{property_key};
-
-Currently, the relationship's properties may be directly accessed as
-if the relationship was a simple hashref. This is a concession to
-backwards compatibility, as the data structure only started being
-blessed as an object in version 0.13.
-
-Relying on this implementation detail is now deprecated.
-Use the accessor methods C<get()> and C<properties()> instead.
-
 =head2 Deletion indicator
 
  $node_exists = ! $relationship->deleted;
